
# FHEM Forum
This module informs you about unread replies and unread posts. You can also filter for specific terms.

# Usage
Login to FHEM forum with stay logged in activated.

```
define fhem.forum fhempy fhem_forum FHEM_COOKIE
```

FHEM_COOKIE: Content of FHEM-Forum588 cookie (yes, it's very long)
